@@ -55,6 +55,8 @@ import com.openexchange.file.storage.FileStorageAccount;
 import com.openexchange.file.storage.FileStorageAccountAccess;
 import com.openexchange.file.storage.oauth.AbstractOAuthFileStorageService;
 import com.openexchange.oauth.KnownApi;
+import com.openexchange.oauth.boxcom.BoxComOAuthScope;
+import com.openexchange.oauth.scope.OAuthScope;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 
@@ -87,4 +89,12 @@ public final class BoxFileStorageService extends AbstractOAuthFileStorageService
         FileStorageAccount account = getAccountAccess(session, accountId);
         return new BoxAccountAccess(this, account, session);
     }
+    
+    /* (non-Javadoc)
+     * @see com.openexchange.file.storage.oauth.AbstractOAuthFileStorageService#getScope()
+     */
+    @Override
+    protected OAuthScope getScope() {
+        return BoxComOAuthScope.drive;
+    }
 }
